summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcombobox_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcombobox_imp.h')
-rw-r--r--kjsembed/qtbindings/qcombobox_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/qtbindings/qcombobox_imp.h b/kjsembed/qtbindings/qcombobox_imp.h
index f625e73b..56a43d5c 100644
--- a/kjsembed/qtbindings/qcombobox_imp.h
+++ b/kjsembed/qtbindings/qcombobox_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TTQComboBox;
+class TQComboBox;
/**
* Namespace containing the KJSEmbed library.
@@ -17,7 +17,7 @@ class TTQComboBox;
namespace KJSEmbed {
/**
* Wrapper class for TTQComboBox methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -98,7 +98,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQComboBox *toTQComboBox( KJS::Object &object );
+ static TQComboBox *toTQComboBox( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -174,7 +174,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQComboBox *instance; // Temp
+ TQComboBox *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class TTQComboBox;
namespace KJSEmbed {
/**
- * Wrapper class for TTQComboBox methods.
+ * Wrapper class for TQComboBox methods.
*
* @author Richard Moore, rich@kde.org